#ifndef Application_h
#define Application_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"
#include "IconEngine.h"

#include <memory>
#include <QBasicTimer>

class SystemTrayIcon;
class StateFrame;
class LogDialog;

//* Main Window singleton object
class Application: public BaseApplication, private Base::Counter<Application>
{

    //* Qt meta object declaration
    Q_OBJECT

    public:

    //* constructor
    explicit Application( CommandLineArguments );

    //* destructor
    /** destructor, even if default, must be here and non-inline,
    in order to be able to have unique_pointers of forward-declared classes
    */
    ~Application() override;

    //*@name modifier
    //@{

    //* create all widgets
    bool realizeWidget() override;

    //@}

    //*@name accessors
    //@{

    //* command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const override;

    //* toggle log action
    QAction& showLogAction() const
    { return *showLogAction_; }

    //* usage
    void usage() const override;

    //* application name
    QString applicationName() const override
    { return "Qssh"; }

    //* application icon
    QIcon applicationIcon() const override
    { return IconEngine::get( ":/qssh.png" ); }

    // application version
    QString applicationVersion() const override
    { return VERSION; }

    //@}

    protected:

    //* timer event
    void timerEvent( QTimerEvent* ) override;

    protected Q_SLOTS:

    //* configuration
    void _configuration() override;

    //* process request from application manager
    bool _processCommand( Server::ServerCommand ) override;

    private:

    //* cvs log display frame
    std::unique_ptr<SystemTrayIcon> systemTrayIcon_;

    //* log dialog
    std::unique_ptr<LogDialog> logDialog_;

    //* toggle log dialog action
    QAction* showLogAction_ = nullptr;

    //* connection timer
    QBasicTimer timer_;

};

#endif
