/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ConfigurationDialog.h"

#include "Debug.h"
#include "GridLayout.h"
#include "IconEngine.h"
#include "IconNames.h"
#include "OptionCheckBox.h"
#include "OptionSpinBox.h"

#include <QGroupBox>
#include <QLabel>
#include <QPushButton>

//_________________________________________________________
ConfigurationDialog::ConfigurationDialog( QWidget* parent, bool supportsSystemNotifications ):
BaseConfigurationDialog( parent )
{

    Debug::Throw( "ConfigurationDialog::ConfigurationDialog.\n" );
    setOptionName( "CONFIGURATION_DIALOG" );

    // base configuration
    baseConfiguration();

    // options
    {
        auto page = &addPage( IconEngine::get( IconNames::PreferencesAppearance ), tr( "Behavior" ), tr( "Application's Behavior" ) );
        auto box = new QWidget( page );
        page->layout()->addWidget( box );

        auto vLayout = new QVBoxLayout;
        vLayout->setSpacing( 5 );
        vLayout->setMargin( 5 );
        box->setLayout( vLayout );

        OptionCheckBox* checkbox;

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use monochrome system tray icon" ), box, "USE_MONOCHROME_SYSTEMTRAY_ICON" ) );
        addOptionWidget( checkbox );

        if( supportsSystemNotifications )
        {
            vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Use system notifications" ), box, "USE_SYSTEM_NOTIFICATIONS" ) );
            addOptionWidget( checkbox );
        }

        vLayout->addWidget( checkbox = new OptionCheckBox( tr( "Automatically reconnect when network becomes available" ), box, "NETWORK_AUTO_RECONNECT" ) );
        addOptionWidget( checkbox );

        QLabel* label;
        OptionSpinBox* spinbox;
        QHBoxLayout* hLayout = new QHBoxLayout;
        hLayout->setMargin(0);
        hLayout->setSpacing(5);
        vLayout->addLayout( hLayout );
        hLayout->addWidget( label = new QLabel( tr( "Network connection check interval:" ), box ) );
        hLayout->addWidget( spinbox = new OptionSpinBox( box, "NETWORK_AUTO_RECONNECT_TIMEOUT" ) );
        spinbox->setSuffix( tr( "s" ) );
        spinbox->setMinimum( 1 );
        spinbox->setToolTip( tr( "Time interval (seconds) between checks" ) );
        addOptionWidget( spinbox );
        label->setBuddy( spinbox );

    }

    // load initial configuration
    read();

}
