#ifndef ConnectionListDialog_h
#define ConnectionListDialog_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CustomDialog.h"
#include "SshConnectionAttributes.h"

#include <QStackedWidget>

class ConnectionListWidget;
class ConnectionWidget;
class TunnelWidget;

//* handles ssh connection attributes
class ConnectionListDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //* constructor
    explicit ConnectionListDialog( QWidget* = nullptr );

    //* set connection attributes
    void setAttributes( const Ssh::ConnectionAttributes::List& );

    //* get connection attributes
    Ssh::ConnectionAttributes::List attributes() const;

    private Q_SLOTS:

    //* ok button clicked
    void _okButtonClicked();

    //* cancel button clicked
    void _cancelButtonClicked();

    //* add
    void _addConnection();

    //* edit
    void _editConnection();

    //* add
    void _addTunnel();

    //* edit
    void _editTunnel();

    private:

    //* set page to a given widget
    void _setCurrentWidget( QWidget* );

    //* stacked widget
    QStackedWidget* stackedWidget_ = nullptr;

    //* connection list widget
    ConnectionListWidget* connectionListWidget_ = nullptr;

    //* connection widget
    ConnectionWidget* connectionWidget_ = nullptr;

    //* tunnel widget
    TunnelWidget* tunnelWidget_ = nullptr;

    //* old connection attributes for edition
    Ssh::ConnectionAttributes attributes_;

    //* old tunnel attributes for editon
    Ssh::TunnelAttributes tunnelAttributes_;

};

#endif
