#ifndef ConnectionObject_h
#define ConnectionObject_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SshConnectionAttributes.h"
#include "Counter.h"
#include "Severity.h"

#include <QAction>
#include <QBasicTimer>
#include <QObject>
#include <QTimerEvent>

//* forward declaration
namespace Ssh { class Connection; }


//* connection widget interface
class ConnectionObject: public QObject, private Base::Counter<ConnectionObject>
{

    Q_OBJECT;

    public:

    //* constructor
    explicit ConnectionObject( QObject* parent );

    //* destructor
    ~ConnectionObject() override;

    //*@name accessors
    //@{

    //* connection attributes
    const Ssh::ConnectionAttributes& attributes() const
    { return attributes_; }

    //* connect
    QAction& connectAction() const
    { return *connectAction_; }

    //@}

    //*@name modifiers
    //@{

    //* connection attributes
    void setAttributes( const Ssh::ConnectionAttributes& attributes );

    //@}

    Q_SIGNALS:

    //* message available
    void messageAvailable( QString, Severity = Default );

    //* connection status changed
    void connected();

    //* disconnected
    void disconnected();

    //* emitted when connection attributes are changed
    void attributesChanged();

    protected:

    //* timer
    void timerEvent( QTimerEvent* ) override;

    protected Q_SLOTS:

    //* connect
    void _toggleConnection( bool );

    private Q_SLOTS:

    //* update connection attributes when connected
    void _updateAttributes();

    //* notify login failed
    void _notifyLoginFailed();

    //* message processing
    void _processMessage( const QString& );

    //* error processing
    void _processError( const QString& );

    private:

    //* actions
    void _installActions();

    //* timer
    QBasicTimer timer_;

    //* attributes
    Ssh::ConnectionAttributes attributes_;

    //* ssh connection
    Ssh::Connection* connection_ = nullptr;

    //* stored state
    bool savedState_ = false;

    //*@name actions
    //@{

    //* connect
    QAction* connectAction_ = nullptr;

    //@}

};

#endif
