#ifndef ConnectionWidget_h
#define ConnectionWidget_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TunnelAttributesModel.h"
#include "SshConnectionAttributes.h"

#include <QCheckBox>
#include <QPushButton>
#include <QSpinBox>

class LineEditor;
class TreeView;

//* handles ssh connection attributes
class ConnectionWidget: public QWidget
{

    Q_OBJECT

    public:

    //* constructor
    explicit ConnectionWidget( QWidget* = nullptr );

    //*@name accessors
    //@{

    //* get connection attributes
    Ssh::ConnectionAttributes attributes() const;

    //* add button
    QPushButton& addButton() const
    { return *addButton_; }

    //* edit button
    QPushButton& editButton() const
    { return *editButton_; }

    //* model
    const TunnelAttributesModel& model() const
    { return model_; }

    //* list
    TreeView& list() const
    { return *list_; }

    //@}

    //*@name modifiers
    //@{

    //* set connection attributes
    void setAttributes( const Ssh::ConnectionAttributes& );

    //* model
    TunnelAttributesModel& model()
    { return model_; }

    //@}

    private Q_SLOTS:

    //* update button enability
    void _updateButtons();

    //* remove
    void _remove();

    private:

    //* name editor
    LineEditor* nameEditor_ = nullptr;

    //* host
    LineEditor* hostEditor_ = nullptr;

    //* port
    QSpinBox* portSpinBox_ = nullptr;

    //* user
    LineEditor* userEditor_ = nullptr;

    //* auto connect
    QCheckBox* rememberPassword_ = nullptr;

    //* auto connect
    QCheckBox* autoConnect_ = nullptr;

    //* tunnel list
    TreeView* list_ = nullptr;

    //* tunnel attributes model
    TunnelAttributesModel model_;

    //* add
    QPushButton* addButton_ = nullptr;

    //* edit
    QPushButton* editButton_ = nullptr;

    //* remove
    QPushButton* removeButton_ = nullptr;

};

#endif
