#ifndef MainMenu_h
#define MainMenu_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SshConnectionAttributes.h"
#include "Counter.h"
#include "Debug.h"
#include "Severity.h"

#include <QBasicTimer>
#include <QMenu>
#include <QSet>
#include <QTimerEvent>

namespace Network
{
    class ConnectionMonitor;
};

//* application main window
class MainMenu: public QMenu, private Base::Counter<MainMenu>
{

    Q_OBJECT

    public:

    //* constructor;
    explicit MainMenu( QWidget* = nullptr );

    //@name accessors
    //@{

    //* return number of connections
    int connectionsCount() const;

    //* configuration
    QAction& configurationAction() const
    { return *configurationAction_; }

    //@}

    //@name modifiers
    //@{

    //* read connections
    void readConnections();

    //* auto connect
    void autoConnect();

    using QMenu::connect;
    using QMenu::disconnect;

    //* connect given connection
    void connect( QString );

    //* disconnect given connection
    void disconnect( QString );

    //* reconnect given connection
    void reconnect( QString );

    //@}

    Q_SIGNALS:

    //* message available
    void messageAvailable( QString, Severity = Default );

    //* connection status changed
    void connectionStatusChanged();

    public Q_SLOTS:

    //* reconnect
    void reconnectExisting();

    //* reconnect all
    void reconnectAll();

    //* close all connections
    void closeConnections();

    protected:

    //* show event
    void showEvent( QShowEvent* ) override;

    private Q_SLOTS:

    //* delayed reconnection
    void _reconnectAllDelayed();

    //* update configuration
    void _updateConfiguration();

    //* connection have been changed and needs to be saved to disk
    void _saveConnections();

    //* configure connections
    void _configureConnections();

    private:

    //* add connection
    void _addConnection( const Ssh::ConnectionAttributes& );

    //* actions
    void _installActions();

    //* connection monitor
    Network::ConnectionMonitor* connectionMonitor_;

    //*@name actions
    //@{

    //* configuration action
    QAction* configurationAction_ = nullptr;

    //* reconnection
    QAction* reconnectAction_ = nullptr;

    //@}

    //* same connection settings
    class SameConnectionFTor
    {

        public:

        //* constructor
        explicit SameConnectionFTor( const Ssh::ConnectionAttributes& attributes ):
            attributes_( attributes )
        {}

        //* predicate
        bool operator() (const Ssh::ConnectionAttributes& ) const;

        private:

        //* prediction
        Ssh::ConnectionAttributes attributes_;

    };


};

#endif
