#ifndef SystemTrayIcon_h
#define SystemTrayIcon_h

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "Severity.h"

#include <QSystemTrayIcon>

#include <memory>

class MainMenu;
class Menu;
class ToolTipWidget;
class SystemNotifications;

namespace Svg
{
    class SvgPlasmaInterface;
}

//* application system tray icon
class SystemTrayIcon: public QSystemTrayIcon, private Base::Counter<SystemTrayIcon>
{

    Q_OBJECT;

    public:

    //* constructor
    explicit SystemTrayIcon( QObject* = nullptr );

    //* destructor
    ~SystemTrayIcon() override;

    //* main window
    MainMenu& mainMenu() const
    { return *mainMenu_; }

    //* menu
    Menu& menu() const
    { return *contextMenu_; }

    //* returns true if system notifications are supported
    bool supportsSystemNotifications() const;

    Q_SIGNALS:

    //* message available
    void messageAvailable( QString );

    protected:

    //* generic event handler
    bool event( QEvent* ) override;

    public Q_SLOTS:

    //* notify
    void notify( QString, Severity = Default );

    protected Q_SLOTS:

    //* activated
    void _activate( QSystemTrayIcon::ActivationReason );

    //* update tooltip
    void _updateToolTip();

    private Q_SLOTS:

    //* configuration
    void _updateConfiguration();

    //* icons
    void _reloadIcon();

    private:

    //* show menu
    void _showMenu( QMenu* ) const;

    //* plasma interface
    std::unique_ptr<Svg::SvgPlasmaInterface> plasmaInterface_;

    //* system notification
    std::unique_ptr<SystemNotifications> systemNotifications_;

    //* tooltip
    std::unique_ptr<ToolTipWidget> toolTipWidget_;

    //* main widget
    std::unique_ptr<MainMenu> mainMenu_;

    //* menu
    std::unique_ptr<Menu> contextMenu_;

};

#endif
