/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ToolTipWidget.h"

#include "ConnectionObject.h"
#include "Debug.h"
#include "GridLayout.h"
#include "GridLayoutItem.h"
#include "QtUtil.h"

#include <QApplication>
#include <QLayout>

//_________________________________________
ToolTipWidget::ToolTipWidget( QWidget* parent ):
    BaseToolTipWidget( parent )
{

    Debug::Throw( "ToolTipWidget::ToolTipWidget.\n" );

    // create objects
    QHBoxLayout *hLayout = new QHBoxLayout;
    hLayout->setMargin(10);
    hLayout->setSpacing(10);
    setLayout( hLayout );

    // pixmap
    hLayout->addWidget( pixmapLabel_ = new QLabel(this), Qt::AlignTop );

    // right side layout
    QVBoxLayout* vLayout = new QVBoxLayout;
    vLayout->setMargin( 0 );
    vLayout->setSpacing( 5 );
    vLayout->addStretch( 1 );

    hLayout->addLayout( vLayout );

    // title
    vLayout->addWidget( titleLabel_ = new QLabel( this ) );
    titleLabel_->setAlignment( Qt::AlignCenter );
    titleLabel_->setFont( QtUtil::titleFont( titleLabel_->font() ) );
    titleLabel_->setMargin( 1 );

    // separator
    vLayout->addWidget( separator_ = new QFrame( this ) );
    separator_->setFrameStyle( QFrame::HLine );

    // grid layout
    vLayout->addLayout( layout_ = new GridLayout );
    layout_->setMargin(0);
    layout_->setMaxCount(2);
    layout_->setColumnAlignment( 0, Qt::AlignVCenter|Qt::AlignRight );
    layout_->setColumnAlignment( 1, Qt::AlignVCenter|Qt::AlignLeft );
    vLayout->addStretch( 1 );

    // install event handlers
    qApp->installEventFilter(this);

}

//__________________________________________
void ToolTipWidget::updateText( QList<ConnectionObject*> connections )
{

    for( const auto& label:findChildren<QLabel*>() )
    {
        if( label == titleLabel_ || label == pixmapLabel_ ) continue;
        delete label;
    }

    if( connections.empty() )
    {

        QLabel* label = new QLabel( tr( "No connections configured" ), this );
        layout_->addWidget( label, 0, 0, 2, 1, Qt::AlignCenter );

    } else {

        for( const auto& connection:connections )
        {
            GridLayoutItem item( this, layout_ );
            item.setKey( connection->attributes().name() + ":" );
            item.setText( connection->connectAction().isChecked() ? tr( "connected" ): tr( "disconnected") );
        }

        layout_->activate();

    }

}

//__________________________________________
bool ToolTipWidget::eventFilter(QObject*, QEvent* event )
{
    switch( event->type() )
    {

        case QEvent::Leave:
        hide();
        break;

        case QEvent::WindowActivate:
        case QEvent::WindowDeactivate:
        case QEvent::MouseButtonPress:
        case QEvent::MouseButtonRelease:
        case QEvent::MouseButtonDblClick:
        case QEvent::FocusIn:
        case QEvent::FocusOut:
        case QEvent::Wheel:
        hide();
        break;

        default:
        break;
    }

    return false;

}
